@@ -53,13 +53,11 @@ void process_inotify(int fd)
 	acpid_log(LOG_DEBUG, "inotify read bytes: %d", bytes);
 
 	/* eof is not expected */	
-	if (bytes == 0)
-	{
+	if (bytes == 0) {
 		acpid_log(LOG_WARNING, "inotify fd eof encountered");
 		return;
 	}
-	else if (bytes < 0)
-	{
+	else if (bytes < 0) {
 		/* EINVAL means buffer wasn't big enough.  See inotify(7). */
 		acpid_log(LOG_ERR, "inotify read error: %s (%d)",
 			strerror(errno), errno);
@@ -70,21 +68,43 @@ void process_inotify(int fd)
 
 	acpid_log(LOG_DEBUG, "inotify name len: %d", eventbuf.event.len);
 
-	/* if a name is included */
-	if (eventbuf.event.len > 0)
-	{
-		const int dnsize = 256;
-		char devname[dnsize];
+	const int dnsize = 256;
+	char devname[dnsize];
 
+	/* if a name is included */
+	if (eventbuf.event.len > 0) {
 		/* devname = ACPID_INPUTLAYERDIR + "/" + pevent -> name */
 		strcpy(devname, ACPID_INPUTLAYERDIR);
 		strcat(devname, "/");
 		strncat(devname, eventbuf.event.name, dnsize - strlen(devname) - 1);
+	}
 		
+	/* if this is a create */
+	if (eventbuf.event.mask & IN_CREATE) {
 		acpid_log(LOG_DEBUG, "inotify about to open: %s", devname);
 
 		open_inputfile(devname);
 	}
+
+	/* if this is a delete */
+	if (eventbuf.event.mask & IN_DELETE) {
+		/* struct connection *c; */
+		
+		acpid_log(LOG_DEBUG, "inotify received a delete for: %s", devname);
+
+#if 0
+/* Switching back to the original ENODEV detection scheme.  See 
+   process_input() in input_layer.c. */
+/* keeping this for future reference */
+		/* search for the event file in the connection list */
+		/* ??? Or should we just have a delete_connection_name()? */
+		c = find_connection_name(devname);
+		
+		/* close that connection if found */
+		if (c)
+			delete_connection(c->fd);
+#endif
+	}
 }
 
 /*-----------------------------------------------------------------*/
@@ -106,8 +126,8 @@ void open_inotify(void)
 	
 	acpid_log(LOG_DEBUG, "inotify fd: %d", fd);
 
-	/* watch for new files being created in /dev/input */
-	wd = inotify_add_watch(fd, ACPID_INPUTLAYERDIR, IN_CREATE);
+	/* watch for files being created or deleted in /dev/input */
+	wd = inotify_add_watch(fd, ACPID_INPUTLAYERDIR, IN_CREATE | IN_DELETE);
 
 	if (wd < 0) {
 		acpid_log(LOG_ERR, "inotify_add_watch() failed: %s (%d)",
@@ -121,6 +141,8 @@ void open_inotify(void)
 	/* add a connection to the list */
 	c.fd = fd;
 	c.process = process_inotify;
+	c.pathname = NULL;
+	c.kybd = 0;
 	add_connection(&c);
 }
 
