@@ -188,6 +188,8 @@ void process_input(int fd)
 	ssize_t nbytes;
 	const char *str;
 	static int nerrs;
+	struct connection *c;
+	char str2[100];
 
 	nbytes = read(fd, &event, sizeof(event));
 
@@ -201,7 +203,8 @@ void process_input(int fd)
 		if (errno == EINTR)
 			return;
 		if (errno == ENODEV) {
-			acpid_log(LOG_WARNING, "input device has been disconnected");
+			acpid_log(LOG_WARNING, "input device has been disconnected, fd %d",
+			          fd);
 			delete_connection(fd);
 			return;
 		}
@@ -225,11 +228,27 @@ void process_input(int fd)
 		return;
 	}
 
+	c = find_connection(fd);
+	
+	/* if we're getting scancodes, we probably have a keyboard */
+	if (event.type == EV_MSC  &&  event.code == MSC_SCAN) {
+		if (c)
+			c->kybd = 1;  /* appears to be a keyboard device */
+	}
+	
 	/* convert the event into a string */
 	str = event_string(event);
 	/* if this is not an event we care about, bail */
 	if (str == NULL)
 		return;
+
+	/* If we suspect this is a keyboard, and we have enough space, tack a 
+	 * "K" on to the end of the event string. */
+	if (c  &&  c->kybd  &&  strnlen(str, sizeof(str2)) <= sizeof(str2) - 3) {
+		strcpy(str2, str);
+		strcat(str2, " K");
+		str = str2;
+	}
 	
 	/* if we're locked, don't process the event */
 	if (locked()) {
@@ -308,18 +327,30 @@ int open_inputfile(const char *filename)
     fcntl(fd, F_SETFD, FD_CLOEXEC);
 
 	if (fd >= 0) {
+		char evname[256];
+		
 		/* if this file doesn't have events we need, indicate failure */
 		if (!has_event(fd)) {
 			close(fd);
 			return -1;
 		}
 
-		acpid_log(LOG_DEBUG, "input layer %s "
-			"opened successfully", filename);
+		/* get this event file's name for debugging */
+		strcpy(evname, "Unknown");
+		ioctl(fd, EVIOCGNAME(sizeof(evname)), evname);
+
+		acpid_log(LOG_DEBUG, "input layer %s (%s) "
+			"opened successfully, fd %d", filename, evname, fd);
 
 		/* add a connection to the list */
 		c.fd = fd;
 		c.process = process_input;
+		/* delete_connection() will free */
+		c.pathname = malloc(strlen(filename) + 1);
+		if (c.pathname)
+			strcpy(c.pathname, filename);
+		/* assume not a keyboard until we see a scancode */
+		c.kybd = 0;
 		add_connection(&c);
 
 		return 0;  /* success */
