@@ -175,5 +175,7 @@ open_sock()
 	/* add a connection to the list */
 	c.fd = fd;
 	c.process = process_sock;
+	c.pathname = NULL;
+	c.kybd = 0;
 	add_connection(&c);
 }
